{% extends "allianceauth/base.html" %}

{% load i18n %}

{% block page_title %}{% translate "Discord Announcements" %}{% endblock %}

{% block content %}
    {% translate "Discord Announcements" as translated_header %}
    {% include "aa_discord_announcements/partials/header/page-header.html" with header_text=translated_header %}

    {% block details %}{% endblock %}
{% endblock %}
